<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
<context>
    <name>AppMain</name>
    <message>
        <location filename="src/common/vlcpalyer.cpp" line="54"/>
        <location filename="src/main.cpp" line="94"/>
        <location filename="src/main.cpp" line="95"/>
        <location filename="src/views/vnotemainwindow.cpp" line="615"/>
        <source>Voice Notes</source>
        <translation>语音记事本</translation>
    </message>
    <message>
        <location filename="src/main.cpp" line="96"/>
        <source>Voice Notes is a lightweight memo tool to make text notes and voice recordings.</source>
        <translation>语音记事本是一款提供文本记事、语音录音记录的轻量级记事工具。</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="616"/>
        <source>Recordings not saved</source>
        <translation>录音未保存</translation>
    </message>
</context>
<context>
    <name>DefaultName</name>
    <message>
        <location filename="src/db/vnotefolderoper.cpp" line="245"/>
        <source>Notebook</source>
        <translation>记事本</translation>
    </message>
    <message>
        <location filename="src/db/vnoteitemoper.cpp" line="228"/>
        <source>Text</source>
        <translation>文本</translation>
    </message>
    <message>
        <location filename="src/db/vnoteitemoper.cpp" line="243"/>
        <location filename="src/importolddata/olddbvisistors.cpp" line="154"/>
        <source>Voice</source>
        <translation>语音</translation>
    </message>
</context>
<context>
    <name>DetailPage</name>
    <message>
        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="213"/>
        <source>%1 notes selected</source>
        <translation>已选择 %1 个笔记</translation>
    </message>
</context>
<context>
    <name>FolderSelectDialog</name>
    <message>
        <location filename="src/dialog/folderselectdialog.cpp" line="217"/>
        <source>Move Notes</source>
        <translation>移动笔记</translation>
    </message>
    <message>
        <location filename="src/dialog/folderselectdialog.cpp" line="244"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>取 消</translation>
    </message>
    <message>
        <location filename="src/dialog/folderselectdialog.cpp" line="245"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>确 定</translation>
    </message>
</context>
<context>
    <name>HomePage</name>
    <message>
        <location filename="src/views/homepage.cpp" line="48"/>
        <source>Create Notebook</source>
        <translation>新建记事本</translation>
    </message>
    <message>
        <location filename="src/views/homepage.cpp" line="60"/>
        <source>Create a notebook to start recording voice and making notes</source>
        <translation>新建一个记事本后，可以开始记录语音及文字</translation>
    </message>
</context>
<context>
    <name>LeftView</name>
    <message>
        <location filename="src/dialog/folderselectdialog.cpp" line="380"/>
        <location filename="src/dialog/folderselectdialog.cpp" line="394"/>
        <source>Move %1 notes (%2, ...) to:</source>
        <translation>移动 %2 等%1个笔记到：</translation>
    </message>
    <message>
        <location filename="src/dialog/folderselectdialog.cpp" line="381"/>
        <location filename="src/dialog/folderselectdialog.cpp" line="384"/>
        <location filename="src/dialog/folderselectdialog.cpp" line="392"/>
        <source>Move the note &quot;%1&quot; to:</source>
        <translation>移动 %1 笔记到：</translation>
    </message>
</context>
<context>
    <name>MiddleView</name>
    <message>
        <location filename="src/views/middleview.cpp" line="303"/>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <location filename="src/views/middleview.cpp" line="1057"/>
        <source>No search results</source>
        <translation>无搜索结果</translation>
    </message>
</context>
<context>
    <name>MiddleViewDelegate</name>
    <message>
        <location filename="src/views/middleviewdelegate.cpp" line="442"/>
        <source>Sticky Notes</source>
        <translation>已置顶</translation>
    </message>
</context>
<context>
    <name>NoteDetailContextMenu</name>
    <message>
        <location filename="src/common/actionmanager.cpp" line="276"/>
        <source>Save as MP3</source>
        <translation>保存为MP3</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="277"/>
        <source>Voice to Text</source>
        <translation>语音转文字</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="278"/>
        <location filename="src/common/actionmanager.cpp" line="305"/>
        <location filename="src/common/actionmanager.cpp" line="331"/>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="279"/>
        <location filename="src/common/actionmanager.cpp" line="306"/>
        <location filename="src/common/actionmanager.cpp" line="332"/>
        <source>Select all</source>
        <translation>全选</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="280"/>
        <location filename="src/common/actionmanager.cpp" line="307"/>
        <location filename="src/common/actionmanager.cpp" line="333"/>
        <source>Copy</source>
        <translation>复制</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="281"/>
        <location filename="src/common/actionmanager.cpp" line="308"/>
        <location filename="src/common/actionmanager.cpp" line="334"/>
        <source>Cut</source>
        <translation>剪切</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="282"/>
        <location filename="src/common/actionmanager.cpp" line="309"/>
        <location filename="src/common/actionmanager.cpp" line="335"/>
        <source>Paste</source>
        <translation>粘贴</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="304"/>
        <source>View</source>
        <translation>查看</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="310"/>
        <source>Save as</source>
        <translation>另存为</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="336"/>
        <source>Text to Speech</source>
        <translation>语音朗读</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="337"/>
        <source>Stop reading</source>
        <translation>停止朗读</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="338"/>
        <source>Speech to Text</source>
        <translation>语音听写</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="339"/>
        <source>Translate</source>
        <translation>文本翻译</translation>
    </message>
</context>
<context>
    <name>NotebookContextMenu</name>
    <message>
        <location filename="src/common/actionmanager.cpp" line="220"/>
        <source>Rename</source>
        <translation>重命名</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="221"/>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="222"/>
        <source>New note</source>
        <translation>新建笔记</translation>
    </message>
</context>
<context>
    <name>NotesContextMenu</name>
    <message>
        <location filename="src/common/actionmanager.cpp" line="195"/>
        <source>Save as HTML</source>
        <translation>保存为HTML</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="196"/>
        <source>Save as TXT</source>
        <translation>保存为TXT</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="200"/>
        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="342"/>
        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="353"/>
        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="359"/>
        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="361"/>
        <source>Save note</source>
        <translation>保存笔记</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="240"/>
        <source>Rename</source>
        <translation>重命名</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="242"/>
        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="336"/>
        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="345"/>
        <source>Move</source>
        <translation>移动</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="243"/>
        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="338"/>
        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="344"/>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="245"/>
        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="343"/>
        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="354"/>
        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="366"/>
        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="368"/>
        <source>Save voice recording</source>
        <translation>保存语音</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="246"/>
        <source>New note</source>
        <translation>新建笔记</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="1258"/>
        <source>Unstick</source>
        <translation>取消置顶</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="1260"/>
        <source>Sticky on Top</source>
        <translation>置顶</translation>
    </message>
</context>
<context>
    <name>Setting</name>
    <message>
        <location filename="src/common/setting.cpp" line="39"/>
        <source>Basic</source>
        <translation>基础设置</translation>
    </message>
    <message>
        <location filename="src/common/setting.cpp" line="40"/>
        <source>Audio Source</source>
        <translation>声音来源</translation>
    </message>
    <message>
        <location filename="src/common/setting.cpp" line="41"/>
        <source>Internal</source>
        <translation>系统声音</translation>
    </message>
    <message>
        <location filename="src/common/setting.cpp" line="42"/>
        <source>Microphone</source>
        <translation>麦克风声音</translation>
    </message>
</context>
<context>
    <name>Shortcuts</name>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="919"/>
        <source>New notebook</source>
        <translation>新建记事本</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="920"/>
        <source>Rename notebook</source>
        <translation>重命名记事本</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="921"/>
        <source>Delete notebook</source>
        <translation>删除记事本</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="943"/>
        <source>New note</source>
        <translation>新建笔记</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="944"/>
        <source>Rename note</source>
        <translation>重命名笔记</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="945"/>
        <source>Delete note</source>
        <translation>删除笔记</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="946"/>
        <source>Play/Pause</source>
        <translation>播放/暂停</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="947"/>
        <source>Record voice</source>
        <translation>录音</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="948"/>
        <source>Save note</source>
        <translation>保存笔记</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="949"/>
        <source>Save recordings</source>
        <translation>保存语音</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="969"/>
        <source>Select all</source>
        <translation>全选</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="970"/>
        <source>Copy</source>
        <translation>复制</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="971"/>
        <source>Cut</source>
        <translation>剪切</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="972"/>
        <source>Paste</source>
        <translation>粘贴</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="973"/>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="996"/>
        <source>Help</source>
        <translation>帮助</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="997"/>
        <source>Display shortcuts</source>
        <translation>显示快捷键</translation>
    </message>
</context>
<context>
    <name>ShortcutsGroups</name>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="925"/>
        <source>Notebooks</source>
        <translation>记事本</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="953"/>
        <source>Notes</source>
        <translation>笔记</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="977"/>
        <source>Edit</source>
        <translation>编辑</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="1001"/>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
</context>
<context>
    <name>SplashView</name>
    <message>
        <location filename="src/views/splashview.cpp" line="46"/>
        <source>Loading...</source>
        <translation>正在加载...</translation>
    </message>
</context>
<context>
    <name>TitleBar</name>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="371"/>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="1889"/>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="1890"/>
        <source>Privacy Policy</source>
        <translation>隐私政策</translation>
    </message>
</context>
<context>
    <name>UpgradeView</name>
    <message>
        <location filename="src/importolddata/upgradeview.cpp" line="50"/>
        <source>Importing notes from the old version, please wait...</source>
        <translation>因产品升级正在导入数据，请稍候...</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <location filename="src/common/utils.cpp" line="56"/>
        <source>1 min ago</source>
        <translation>1分钟前</translation>
    </message>
    <message>
        <location filename="src/common/utils.cpp" line="58"/>
        <source>%1 mins ago</source>
        <translation>%1分钟前</translation>
    </message>
    <message>
        <location filename="src/common/utils.cpp" line="64"/>
        <source>Yesterday</source>
        <translation>昨天</translation>
    </message>
</context>
<context>
    <name>VNoteErrorMessage</name>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="881"/>
        <source>The voice conversion failed due to the poor network connection, please have a check</source>
        <translation>当前网络状态差，语音转写失败，请确保网络畅通</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="885"/>
        <source>Voice to text conversion failed</source>
        <translation>语音转文字失败</translation>
    </message>
</context>
<context>
    <name>VNoteMainWindow</name>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="470"/>
        <source>Create Notebook</source>
        <translation>新建记事本</translation>
    </message>
</context>
<context>
    <name>VNoteMessageDialog</name>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="53"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>确 定</translation>
    </message>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="132"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>取 消</translation>
    </message>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="133"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>确 定</translation>
    </message>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="136"/>
        <source>Are you sure you want to delete this notebook?
All notes in it will be deleted</source>
        <translation>您确定要删除这个记事本吗？
包含的所有笔记将被删除</translation>
    </message>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="139"/>
        <source>Do you want to stop the current recording?</source>
        <translation>当前录音中，是否停止录音？</translation>
    </message>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="143"/>
        <source>Are you sure you want to delete the selected %1 notes?</source>
        <translation>您确定要删除选中的%1条笔记吗？</translation>
    </message>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="145"/>
        <source>Are you sure you want to delete this note?</source>
        <translation>您确定要删除这条笔记吗？</translation>
    </message>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="149"/>
        <source>Cannot convert this voice note, as notes over 20 minutes are not supported at present.</source>
        <translation>无法转写此条语音笔记，暂仅支持20分钟内的语音笔记。</translation>
    </message>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="153"/>
        <source>Converting a voice note now. Do you want to stop it?</source>
        <translation>当前有语音笔记正在转写中，是否确定关闭？</translation>
    </message>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="156"/>
        <source>The low input volume may result in bad recordings. Do you want to continue?</source>
        <translation>当前系统输入音量低，可能影响录音效果。是否继续录音？</translation>
    </message>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="159"/>
        <source>The clipped recordings and converted text will not be pasted. Do you want to continue?</source>
        <translation>语音笔记以及转写文字剪切后不能粘贴，是否继续？</translation>
    </message>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="162"/>
        <source>Save failed</source>
        <translation>保存失败</translation>
    </message>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="166"/>
        <source>You do not have permission to save files there</source>
        <translation>您没有权限在此位置保存这类文件</translation>
    </message>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="170"/>
        <source>The voice note has been deleted</source>
        <translation>该语音笔记已被删除</translation>
    </message>
</context>
<context>
    <name>VNoteRecordBar</name>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="1736"/>
        <source>Your audio recording device does not work.</source>
        <translation>您的录音设备异常，无法录制语音。</translation>
    </message>
    <message>
        <location filename="src/views/vnoterecordbar.cpp" line="249"/>
        <source>No recording device detected</source>
        <translation>未检测到录音设备</translation>
    </message>
</context>
<context>
    <name>VoiceNoteItem</name>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="1679"/>
        <source>Converting voice to text</source>
        <translation>正在转为文字...</translation>
    </message>
</context>
<context>
    <name>web</name>
    <message>
        <location filename="src/common/jscontent.cpp" line="141"/>
        <source>Font</source>
        <translation>字体</translation>
    </message>
    <message>
        <location filename="src/common/jscontent.cpp" line="142"/>
        <source>Font size</source>
        <translation>字号</translation>
    </message>
    <message>
        <location filename="src/common/jscontent.cpp" line="143"/>
        <source>Font color</source>
        <translation>字体颜色</translation>
    </message>
    <message>
        <location filename="src/common/jscontent.cpp" line="144"/>
        <source>Text highlight color</source>
        <translation>背景色</translation>
    </message>
    <message>
        <location filename="src/common/jscontent.cpp" line="145"/>
        <source>Bold</source>
        <translation>加粗</translation>
    </message>
    <message>
        <location filename="src/common/jscontent.cpp" line="146"/>
        <source>Italic</source>
        <translation>斜体</translation>
    </message>
    <message>
        <location filename="src/common/jscontent.cpp" line="147"/>
        <source>Underline</source>
        <translation>下划线</translation>
    </message>
    <message>
        <location filename="src/common/jscontent.cpp" line="148"/>
        <source>Strikethrough</source>
        <translation>删除线</translation>
    </message>
    <message>
        <location filename="src/common/jscontent.cpp" line="149"/>
        <source>Bullets</source>
        <translation>无序列表</translation>
    </message>
    <message>
        <location filename="src/common/jscontent.cpp" line="150"/>
        <source>Numbering</source>
        <translation>有序列表</translation>
    </message>
    <message>
        <location filename="src/common/jscontent.cpp" line="151"/>
        <source>More colors</source>
        <translation>更多颜色</translation>
    </message>
    <message>
        <location filename="src/common/jscontent.cpp" line="152"/>
        <source>Recent</source>
        <translation>最近使用</translation>
    </message>
</context>
</TS>